%define oname lua
%define major 5.3
%define libname %mklibname %{oname} %{major}
%define develname %mklibname %{oname} %{major} -d
%define staticname %mklibname %{oname} %{major} -s -d
%define alt_priority %(echo %{major} | sed -e 's/[^0-9]//g')

Summary:	Powerful, light-weight programming language
Name:		%{oname}%{major}
Version:	5.3.5
Release:	%mkrel 2
License:	MIT
Group:		Development/Other
URL:		http://www.lua.org/
Source0:	http://www.lua.org/ftp/%{oname}-%{version}.tar.xz
Source1:	lua.pc
Patch0:		lua-5.2.1-dynlib.patch
Patch2:		lua-5.3.4-modules_path.patch
Patch9:		CVE-2019-6706-use-after-free-lua_upvaluejoin.patch
Patch10:	lua-5.3.5-CVE-2020-24370.patch
Provides:	lua%{major}
Requires(post):	update-alternatives
Requires(postun):	update-alternatives
BuildRequires:	readline-devel
BuildRequires:	pkgconfig(ncurses)

%description
Lua is a programming language originally designed for extending applications,
but also frequently used as a general-purpose, stand-alone language. Lua
combines simple procedural syntax (similar to Pascal) with powerful data
description constructs based on associative arrays and extensible semantics.
Lua is dynamically typed, interpreted from bytecodes, and has automatic memory
management, making it ideal for configuration, scripting, and rapid
prototyping. Lua is implemented as a small library of C functions, written in
ANSI C, and compiles unmodified in all known platforms. The implementation
goals are simplicity, efficiency, portability, and low embedding cost.

%package -n %{libname}
Summary:	Powerful, light-weight programming language
Group:		System/Libraries

%description -n %{libname}
Lua is a programming language originally designed for extending applications,
but also frequently used as a general-purpose, stand-alone language. Lua
combines simple procedural syntax (similar to Pascal) with powerful data
description constructs based on associative arrays and extensible semantics.
Lua is dynamically typed, interpreted from bytecodes, and has automatic memory
management, making it ideal for configuration, scripting, and rapid
prototyping. Lua is implemented as a small library of C functions, written in
ANSI C, and compiles unmodified in all known platforms. The implementation
goals are simplicity, efficiency, portability, and low embedding cost.

%package -n %{develname}
Summary:	Headers and development files for Lua
Group:		Development/Libraries
Requires:	%{libname} = %{version}-%{release}
Requires:	%{name} = %{version}-%{release}
Provides:	liblua%{major}-devel = %{version}-%{release}
Provides:	lua%{major}-devel = %{version}-%{release}
Conflicts:	lib64lua5.1-devel
Conflicts:  lib64lua5.2-devel


%description -n %{develname}
This package contains the headers and development files for Lua.

%package -n	%{staticname}
Summary:	Static development files for Lua
Group:		Development/Libraries
Provides:	lua-devel-static = %{version}-%{release}
Provides:	lua-static-devel = %{version}-%{release}
Requires:	%{develname} = %{version}-%{release}
Conflicts:	lib64lua5.1-static-devel
Conflicts:  lib64lua5.2-static-devel

%description -n	%{staticname}
This package contains the static development files for Lua.

%prep
%setup -q -n %{oname}-%{version}
%patch0 -p1 -b .dynlib
mkdir -p etc
cp %{SOURCE1} ./etc/
sed -i -e 's/@MAJOR_VERSION@/%{major}/g' ./etc/lua.pc
sed -i -e 's/@FULL_VERSION@/%{version}/g' ./etc/lua.pc

sed -i -e "s|/usr/local|%{_prefix}|g" Makefile
sed -i -e "s|/lib|/%{_lib}|g" Makefile
sed -i -e "s|/usr/local|%{_prefix}|g" src/luaconf.h
sed -i -e "s|/lib|/%{_lib}|g" src/luaconf.h
sed -i -e "s|/man/man1|/share/man/man1|g" Makefile
sed -i -e "s|\$(V)|%{major}|g" src/Makefile

%patch2 -p1
%patch9 -p1 -b .CVE-2019-6706
%patch10 -p1 -b .CVE-2020-24370

%build
sed -i 's/-lncurses/-lncursesw/g' */Makefile*
# (tv) enable compat module (fix building rpm with lua-5.2):
%make_build linux CFLAGS="%{optflags} -fPIC -DLUA_USE_LINUX -DLUA_COMPAT_MODULE -DLUA_COMPAT_BITLIB -DLUA_COMPAT_APIINTCASTS"

%install
%make_install INSTALL_TOP=%{buildroot}%{_prefix} INSTALL_LIB=%{buildroot}%{_libdir} INSTALL_MAN=%{buildroot}%{_mandir}/man1
install -d %{buildroot}%{_libdir}/lua/%{major}/
install -d %{buildroot}%{_datadir}/lua/%{major}/

install -m 755 src/liblua.so.%{major}* %{buildroot}%{_libdir}
ln -s liblua.so.%{major} %{buildroot}%{_libdir}/liblua.so

install -d -m 755 %{buildroot}%{_libdir}/pkgconfig/
install -m 644 etc/lua.pc %{buildroot}%{_libdir}/pkgconfig/

# for update-alternatives
mv %{buildroot}%{_bindir}/lua %{buildroot}%{_bindir}/lua%{major}
mv %{buildroot}%{_bindir}/luac %{buildroot}%{_bindir}/luac%{major}

%post
/usr/sbin/update-alternatives --install %{_bindir}/lua lua %{_bindir}/lua%{major} %{alt_priority} --slave %{_bindir}/luac luac %{_bindir}/luac%{major}

%postun
[[ -f %{_bindir}/lua%{major} ]] || /usr/sbin/update-alternatives --remove lua %{_bindir}/lua%{major}

%files
%doc doc/*{.html,.css,.gif,.png}
%doc README
%{_bindir}/*
%{_mandir}/man1/*
%dir %{_datadir}/lua/%{major}

%files -n %{libname}
%{_libdir}/liblua.so.%{major}
%dir %{_libdir}/lua/%{major}

%files -n %{develname}
%{_includedir}/*
%{_libdir}/pkgconfig/*
%{_libdir}/liblua.so

%files -n %{staticname}
%{_libdir}/*.a


%changelog
* Thu Dec 31 2020 tex - 5.3.5-2pclos2020
- rebuild for new readline
